package com.op.mes.service;

import com.op.common.core.domain.BaseFileData;
import com.op.mes.domain.BaseFile;

import java.util.List;

/**
 * 附件Service接口
 *
 * @author Open Platform
 * @date 2023-07-10
 */
public interface IBaseFileService {
	/**
	 * 查询附件
	 *
	 * @param fileId 附件主键
	 * @return 附件
	 */
	public BaseFile selectBaseFileByFileId(String fileId);

	/**
	 * 查询附件列表
	 *
	 * @param baseFile 附件
	 * @return 附件集合
	 */
	public List<BaseFile> selectBaseFileList(BaseFile baseFile);

	/**
	 * 新增附件
	 *
	 * @param baseFile 附件
	 * @return 结果
	 */
	public int insertBaseFile(BaseFile baseFile);

	/**
	 * 修改附件
	 *
	 * @param baseFile 附件
	 * @return 结果
	 */
	public int updateBaseFile(BaseFile baseFile);

	/**
	 * 批量删除附件
	 *
	 * @param fileIds 需要删除的附件主键集合
	 * @return 结果
	 */
	public int deleteBaseFileByFileIds(String[] fileIds);

	/**
	 * 删除附件信息
	 *
	 * @param fileId 附件主键
	 * @return 结果
	 */
	public int deleteBaseFileByFileId(String fileId);

    public Boolean insertBaseFileBatch(List<BaseFileData> baseFiles);
}
